@@ -598,7 +598,7 @@ class CommandLineTool(Process):
                 if isinstance(t, Mapping) and "entry" in t:
                     # Dirent
                     entry_field = cast(str, t["entry"])
-                    # the schema guarentees that 'entry' is a string, so the cast is safe
+                    # the schema guarantees that 'entry' is a string, so the cast is safe
                     entry = builder.do_eval(entry_field, strip_whitespace=False)
                     if entry is None:
                         continue
@@ -634,7 +634,7 @@ class CommandLineTool(Process):
                                 )
                             for e in entry:
                                 ec = cast(CWLObjectType, e)
-                                ec["writeable"] = t.get("writable", False)
+                                ec["writable"] = t.get("writable", False)
                             ls.extend(cast(List[CWLObjectType], entry))
                             continue
 
@@ -850,11 +850,18 @@ class CommandLineTool(Process):
             _check_adjust = partial(
                 check_adjust, self.path_check_mode.value, cachebuilder
             )
+            _checksum = partial(
+                compute_checksums,
+                runtimeContext.make_fs_access(runtimeContext.basedir),
+            )
             visit_class(
                 [cachebuilder.files, cachebuilder.bindings],
                 ("File", "Directory"),
                 _check_adjust,
             )
+            visit_class(
+                [cachebuilder.files, cachebuilder.bindings], ("File"), _checksum
+            )
 
             cmdline = flatten(
                 list(map(cachebuilder.generate_arg, cachebuilder.bindings))
@@ -895,14 +902,19 @@ class CommandLineTool(Process):
                         return cast(Optional[str], e["checksum"])
                 return None
 
+            def remove_prefix(s: str, prefix: str) -> str:
+                # replace with str.removeprefix when Python 3.9+
+                return s[len(prefix) :] if s.startswith(prefix) else s
+
             for location, fobj in cachebuilder.pathmapper.items():
                 if fobj.type == "File":
                     checksum = calc_checksum(location)
                     fobj_stat = os.stat(fobj.resolved)
+                    path = remove_prefix(fobj.resolved, runtimeContext.basedir + "/")
                     if checksum is not None:
-                        keydict[fobj.resolved] = [fobj_stat.st_size, checksum]
+                        keydict[path] = [fobj_stat.st_size, checksum]
                     else:
-                        keydict[fobj.resolved] = [
+                        keydict[path] = [
                             fobj_stat.st_size,
                             int(fobj_stat.st_mtime * 1000),
                         ]
@@ -1377,12 +1389,7 @@ class CommandLineTool(Process):
                             prefix = fs_access.glob(outdir)
                             sorted_glob_result = sorted(
                                 fs_access.glob(fs_access.join(outdir, gb)),
-                                key=cmp_to_key(
-                                    cast(
-                                        Callable[[str, str], int],
-                                        locale.strcoll,
-                                    )
-                                ),
+                                key=cmp_to_key(locale.strcoll),
                             )
                             r.extend(
                                 [
