@@ -1,5 +1,6 @@
 """Visualize a CWL workflow."""
 from pathlib import Path
+from typing import Iterator, List, cast
 from urllib.parse import urlparse
 
 import pydot
@@ -32,19 +33,33 @@ class CWLViewer:
     def _set_inner_edges(self) -> None:
         with open(_get_inner_edges_query_path) as f:
             get_inner_edges_query = f.read()
-        inner_edges = self._rdf_graph.query(
-            get_inner_edges_query, initBindings={"root_graph": self._root_graph_uri}
-        )
+        inner_edges = cast(
+            Iterator[rdflib.query.ResultRow],
+            self._rdf_graph.query(
+                get_inner_edges_query, initBindings={"root_graph": self._root_graph_uri}
+            ),
+        )  # ResultRow because the query is of type SELECT
         for inner_edge_row in inner_edges:
             source_label = (
                 inner_edge_row["source_label"]
                 if inner_edge_row["source_label"] is not None
                 else urlparse(inner_edge_row["source_step"]).fragment
             )
+            # Node color and style depend on class
+            source_color = (
+                "#F3CEA1"
+                if inner_edge_row["source_step_class"].endswith("Workflow")
+                else "lightgoldenrodyellow"
+            )
+            source_style = (
+                "dashed"
+                if inner_edge_row["source_step_class"].endswith("Operation")
+                else "filled"
+            )
             n = pydot.Node(
                 "",
-                fillcolor="lightgoldenrodyellow",
-                style="filled",
+                fillcolor=source_color,
+                style=source_style,
                 label=source_label,
                 shape="record",
             )
@@ -55,10 +70,21 @@ class CWLViewer:
                 if inner_edge_row["target_label"] is not None
                 else urlparse(inner_edge_row["target_step"]).fragment
             )
+
+            target_color = (
+                "#F3CEA1"
+                if inner_edge_row["target_step_class"].endswith("Workflow")
+                else "lightgoldenrodyellow"
+            )
+            target_style = (
+                "dashed"
+                if inner_edge_row["target_step_class"].endswith("Operation")
+                else "filled"
+            )
             n = pydot.Node(
                 "",
-                fillcolor="lightgoldenrodyellow",
-                style="filled",
+                fillcolor=target_color,
+                style=target_style,
                 label=target_label,
                 shape="record",
             )
@@ -81,9 +107,12 @@ class CWLViewer:
         inputs_subgraph.set("style", "dashed")
         inputs_subgraph.set("label", "Workflow Inputs")
 
-        input_edges = self._rdf_graph.query(
-            get_input_edges_query, initBindings={"root_graph": self._root_graph_uri}
-        )
+        input_edges = cast(
+            Iterator[rdflib.query.ResultRow],
+            self._rdf_graph.query(
+                get_input_edges_query, initBindings={"root_graph": self._root_graph_uri}
+            ),
+        )  # ResultRow because the query is of type SELECT
         for input_row in input_edges:
             n = pydot.Node(
                 "",
@@ -108,9 +137,12 @@ class CWLViewer:
         outputs_graph.set("style", "dashed")
         outputs_graph.set("label", "Workflow Outputs")
         outputs_graph.set("labelloc", "b")
-        output_edges = self._rdf_graph.query(
-            get_output_edges, initBindings={"root_graph": self._root_graph_uri}
-        )
+        output_edges = cast(
+            Iterator[rdflib.query.ResultRow],
+            self._rdf_graph.query(
+                get_output_edges, initBindings={"root_graph": self._root_graph_uri}
+            ),
+        )  # ResultRow because the query is of type SELECT
         for output_edge_row in output_edges:
             n = pydot.Node(
                 "",
@@ -128,11 +160,14 @@ class CWLViewer:
     def _get_root_graph_uri(self) -> rdflib.URIRef:
         with open(_get_root_query_path) as f:
             get_root_query = f.read()
-        root = list(
-            self._rdf_graph.query(
-                get_root_query,
-            )
-        )
+        root = cast(
+            List[rdflib.query.ResultRow],
+            list(
+                self._rdf_graph.query(
+                    get_root_query,
+                )
+            ),
+        )  # ResultRow because the query is of type SELECT
         if len(root) != 1:
             raise RuntimeError(
                 "Cannot identify root workflow! Notice that only Workflows can be visualized"
