@@ -79,7 +79,7 @@ def relink_initialworkdir(
     container_outdir: str,
     inplace_update: bool = False,
 ) -> None:
-    for _, vol in pathmapper.items():
+    for _, vol in pathmapper.items_exclude_children():
         if not vol.staged:
             continue
 
@@ -88,7 +88,7 @@ def relink_initialworkdir(
         ):
             if not vol.target.startswith(container_outdir):
                 # this is an input file written outside of the working
-                # directory, so therefor ineligable for being an output file.
+                # directory, so therefore ineligable for being an output file.
                 # Thus, none of our business
                 continue
             host_outdir_tgt = os.path.join(
@@ -250,7 +250,7 @@ class JobBase(HasReqsHints, metaclass=ABCMeta):
         `runtime` is the list of arguments to put at the start of the
         command (e.g. docker run).
 
-        `env` is the enviroment to be set for running the resulting
+        `env` is the environment to be set for running the resulting
         command line.
         """
         scr = self.get_requirement("ShellCommandRequirement")[0]
@@ -900,7 +900,7 @@ class ContainerCommandLineJob(JobBase, metaclass=ABCMeta):
                     try:
                         os.remove(cidfile)
                     except OSError as exc:
-                        _logger.warn(
+                        _logger.warning(
                             "Ignored error cleaning up Docker cidfile: %s", exc
                         )
                     return
@@ -923,7 +923,7 @@ class ContainerCommandLineJob(JobBase, metaclass=ABCMeta):
                 process.wait()
                 stats_proc.kill()
         except OSError as exc:
-            _logger.warn("Ignored error with docker stats: %s", exc)
+            _logger.warning("Ignored error with docker stats: %s", exc)
             return
         max_mem_percent = 0  # type: float
         mem_percent = 0  # type: float
