@@ -379,14 +379,14 @@ def match_types(
 
 def object_from_state(
     state: Dict[str, Optional[WorkflowStateItem]],
-    parms: ParametersType,
+    params: ParametersType,
     frag_only: bool,
     supportsMultipleInput: bool,
     sourceField: str,
     incomplete: bool = False,
 ) -> Optional[CWLObjectType]:
     inputobj = {}  # type: CWLObjectType
-    for inp in parms:
+    for inp in params:
         iid = original_id = cast(str, inp["id"])
         if frag_only:
             iid = shortname(iid)
