@@ -1008,8 +1008,7 @@ def test_var_spool_cwl_checker3() -> None:
 
 def test_print_dot() -> None:
     # print Workflow
-    cwl_path = get_data("tests/wf/revsort.cwl")
-    cwl_posix_path = Path(cwl_path).as_posix()
+    cwl_path = get_data("tests/wf/three_step_color.cwl")
     expected_dot = pydot.graph_from_dot_data(
         """
     digraph {{
@@ -1023,11 +1022,8 @@ def test_print_dot() -> None:
                         rank=same,
                         style=dashed
                 ];
-                "file://{cwl_posix_path}#workflow_input"      [fillcolor="#94DDF4",
-                        label=workflow_input,
-                        style=filled];
-                "file://{cwl_posix_path}#reverse_sort"        [fillcolor="#94DDF4",
-                        label=reverse_sort,
+                "file_input"        [fillcolor="#94DDF4",
+                        label=file_input,
                         style=filled];
         }}
         subgraph cluster_outputs {{
@@ -1036,35 +1032,38 @@ def test_print_dot() -> None:
                         rank=same,
                         style=dashed
                 ];
-                "file://{cwl_posix_path}#sorted_output"       [fillcolor="#94DDF4",
-                        label=sorted_output,
+                "file_output"       [fillcolor="#94DDF4",
+                        label=file_output,
+                        style=filled];
+                "string_output"       [fillcolor="#94DDF4",
+                        label=string_output,
                         style=filled];
         }}
-        "file://{cwl_posix_path}#rev" [fillcolor=lightgoldenrodyellow,
-                label=rev,
+        "nested_workflow" [fillcolor="#F3CEA1",
+                label=nested_workflow,
                 style=filled];
-        "file://{cwl_posix_path}#sorted"      [fillcolor=lightgoldenrodyellow,
-                label=sorted,
+        "operation"      [fillcolor=lightgoldenrodyellow,
+                label=operation,
+                style=dashed];
+        "command_line_tool"      [fillcolor=lightgoldenrodyellow,
+                label=command_line_tool,
                 style=filled];
-        "file://{cwl_posix_path}#rev" -> "file://{cwl_posix_path}#sorted";
-        "file://{cwl_posix_path}#sorted" -> "file://{cwl_posix_path}#sorted_output";
-        "file://{cwl_posix_path}#workflow_input" -> "file://{cwl_posix_path}#rev";
-        "file://{cwl_posix_path}#reverse_sort" -> "file://{cwl_posix_path}#sorted";
+        "file_input" -> "nested_workflow";
+        "nested_workflow" -> "operation";
+        "operation" -> "command_line_tool";
+        "operation" -> "string_output";
+        "command_line_tool" -> "file_output";
 }}
-    """.format(
-            cwl_posix_path=cwl_posix_path
-        )
+    """.format()
     )[0]
     stdout = StringIO()
     assert main(["--debug", "--print-dot", cwl_path], stdout=stdout) == 0
     computed_dot = pydot.graph_from_dot_data(stdout.getvalue())[0]
     computed_edges = sorted(
-        (urlparse(source).fragment, urlparse(target).fragment)
-        for source, target in computed_dot.obj_dict["edges"]
+        (source, target) for source, target in computed_dot.obj_dict["edges"]
     )
     expected_edges = sorted(
-        (urlparse(source).fragment, urlparse(target).fragment)
-        for source, target in expected_dot.obj_dict["edges"]
+        (source, target) for source, target in expected_dot.obj_dict["edges"]
     )
     assert computed_edges == expected_edges
 
@@ -1188,7 +1187,7 @@ def test_cid_file_w_prefix(tmp_path: Path, factor: str) -> None:
 
 @needs_docker
 @pytest.mark.parametrize("factor", test_factors)
-def test_secondary_files_v1_1(factor: str) -> None:
+def test_secondary_files_v1_1(factor: str, tmp_path: Path) -> None:
     test_file = "secondary-files.cwl"
     test_job_file = "secondary-files-job.yml"
     try:
@@ -1197,6 +1196,8 @@ def test_secondary_files_v1_1(factor: str) -> None:
         commands.extend(
             [
                 "--debug",
+                "--outdir",
+                str(tmp_path),
                 get_data(os.path.join("tests", test_file)),
                 get_data(os.path.join("tests", test_job_file)),
             ]
@@ -1204,7 +1205,7 @@ def test_secondary_files_v1_1(factor: str) -> None:
         error_code, _, stderr = get_main_output(commands)
     finally:
         # 664 in octal, '-rw-rw-r--'
-        assert stat.S_IMODE(os.stat("lsout").st_mode) == 436
+        assert stat.S_IMODE(os.stat(tmp_path / "lsout").st_mode) == 436
         os.umask(old_umask)  # revert back to original umask
     stderr = re.sub(r"\s\s+", " ", stderr)
     assert "completed success" in stderr
@@ -1213,13 +1214,15 @@ def test_secondary_files_v1_1(factor: str) -> None:
 
 @needs_docker
 @pytest.mark.parametrize("factor", test_factors)
-def test_secondary_files_bad_v1_1(factor: str) -> None:
+def test_secondary_files_bad_v1_1(factor: str, tmp_path: Path) -> None:
     """Affirm the correct error message for a bad secondaryFiles expression."""
     test_file = "secondary-files-bad.cwl"
     test_job_file = "secondary-files-job.yml"
     commands = factor.split()
     commands.extend(
         [
+            "--outdir",
+            str(tmp_path),
             get_data(os.path.join("tests", test_file)),
             get_data(os.path.join("tests", test_job_file)),
         ]
@@ -1282,7 +1285,7 @@ def test_wf_without_container(tmp_path: Path, factor: str) -> None:
 @needs_docker
 @pytest.mark.parametrize("factor", test_factors)
 def test_issue_740_fixed(tmp_path: Path, factor: str) -> None:
-    """Confirm that re-running a particular workflow with caching suceeds."""
+    """Confirm that re-running a particular workflow with caching succeeds."""
     test_file = "cache_test_workflow.cwl"
     cache_dir = str(tmp_path / "cwltool_cache")
     commands = factor.split()
@@ -1302,6 +1305,46 @@ def test_issue_740_fixed(tmp_path: Path, factor: str) -> None:
     assert error_code == 0, stderr
 
 
+@needs_docker
+@pytest.mark.parametrize("factor", test_factors)
+def test_cache_relative_paths(tmp_path: Path, factor: str) -> None:
+    """Confirm that re-running a particular workflow with caching succeeds."""
+    test_file = "secondary-files.cwl"
+    test_job_file = "secondary-files-job.yml"
+    cache_dir = str(tmp_path / "cwltool_cache")
+    commands = factor.split()
+    commands.extend(
+        [
+            "--cachedir",
+            cache_dir,
+            get_data(f"tests/{test_file}"),
+            get_data(f"tests/{test_job_file}"),
+        ]
+    )
+    error_code, _, stderr = get_main_output(commands)
+
+    stderr = re.sub(r"\s\s+", " ", stderr)
+    assert "completed success" in stderr
+    assert error_code == 0
+
+    commands = factor.split()
+    commands.extend(
+        [
+            "--cachedir",
+            cache_dir,
+            get_data(f"tests/{test_file}"),
+            get_data(f"tests/{test_job_file}"),
+        ]
+    )
+    error_code, _, stderr = get_main_output(commands)
+
+    stderr = re.sub(r"\s\s+", " ", stderr)
+    assert "Output of job will be cached in" not in stderr
+    assert error_code == 0, stderr
+
+    assert (tmp_path / "cwltool_cache" / "27903451fc1ee10c148a0bdeb845b2cf").exists()
+
+
 @needs_docker
 def test_compute_checksum() -> None:
     runtime_context = RuntimeContext()
@@ -1600,7 +1643,7 @@ def test_arguments_self() -> None:
             factory.loading_context.singularity = True
         elif not shutil.which("jq"):
             pytest.skip(
-                "Need a container engine (docker, podman, or signularity) or jq to run this test."
+                "Need a container engine (docker, podman, or singularity) or jq to run this test."
             )
         else:
             factory.runtime_context.use_container = False
@@ -1706,10 +1749,10 @@ def test_record_default_with_long() -> None:
     )
 
 
-def test_record_outputeval() -> None:
+def test_record_outputeval(tmp_path: Path) -> None:
     """Confirm that record types can be populated from outputEval."""
     tool_path = get_data("tests/wf/record_outputeval.cwl")
-    err_code, stdout, stderr = get_main_output([tool_path])
+    err_code, stdout, stderr = get_main_output(["--outdir", str(tmp_path), tool_path])
     assert err_code == 0
     result = json.loads(stdout)["references"]
     assert "genome_fa" in result
