@@ -25,6 +25,25 @@ def test_empty_file_creation() -> None:
     assert err_code == 0
 
 
+def test_passthrough_successive(tmp_path: Path) -> None:
+    """An empty file can be successively passed through a subdir of InitialWorkingDirectory."""
+    err_code, _, _ = get_main_output(
+        [
+            "--outdir",
+            str(tmp_path),
+            get_data("tests/wf/iwdr-passthrough-successive.cwl"),
+        ]
+    )
+    assert err_code == 0
+    children = sorted(
+        tmp_path.glob("*")
+    )  # This input directory should be left pristine.
+    assert len(children) == 1
+    subdir = tmp_path / children[0]
+    assert len(sorted(subdir.glob("*"))) == 1
+    assert (subdir / "file").exists()
+
+
 @needs_docker
 def test_directory_literal_with_real_inputs_inside(tmp_path: Path) -> None:
     """Cope with unmoveable files in the output directory created by Docker+IWDR."""
